==> apache-celeborn-0.4.3-source.tgz: apache-celeborn-0.4.3-source/common/src/main/java/org/apache/celeborn/common/network/client/TransportClientBootstrap.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.celeborn.common.network.client;

import io.netty.channel.Channel;

/**
 * A bootstrap which is executed on a TransportClient before it is returned to the user. This
 * enables an initial exchange of information (e.g., SASL authentication tokens) on a once-per-
 * connection basis.
 *
 * <p>Since connections (and TransportClients) are reused as much as possible, it is generally
 * reasonable to perform an expensive bootstrapping operation, as they often share a lifespan with
 * the JVM itself.
 */
public interface TransportClientBootstrap {
  /**
   * Performs the bootstrapping operation, throwing an exception on failure.
   *
   * @param client the transport client to bootstrap
   * @param channel the associated channel with the transport client
   * @throws RuntimeException
   */
  void doBootstrap(TransportClient client, Channel channel) throws RuntimeException;
}

==> apache-celeborn-0.5.4-source.tgz: apache-celeborn-0.5.4-source/common/src/main/java/org/apache/celeborn/common/network/client/TransportClientBootstrap.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.celeborn.common.network.client;

/**
 * A bootstrap which is executed on a TransportClient before it is returned to the user. This
 * enables an initial exchange of information (e.g., SASL authentication tokens) on a once-per-
 * connection basis.
 *
 * <p>Since connections (and TransportClients) are reused as much as possible, it is generally
 * reasonable to perform an expensive bootstrapping operation, as they often share a lifespan with
 * the JVM itself.
 */
public interface TransportClientBootstrap {
  /**
   * Performs the bootstrapping operation, throwing an exception on failure.
   *
   * @param client the transport client to bootstrap
   * @param channel the associated channel with the transport client
   * @throws RuntimeException
   */
  void doBootstrap(TransportClient client) throws RuntimeException;
}
